@@ -125,7 +125,7 @@ class ApiQuery:
         return self._wrap().__await__()
 
     async def _wrap(self):
-        self.params['q'] = '+'.join(self.q)
+        self.params['q'] = '+'.join(sorted(self.q))
         resp = await self.session._call_api(self.params)
         root = ET.fromstring(resp.text)
         results = [
